@@ -57,8 +57,7 @@ CST_SplitDim <- function(data, split_dim = 'time', indices = NULL,
                          insert_ftime = NULL) {
   # Check 's2dv_cube'
   if (!inherits(data, 's2dv_cube')) {
-    stop("Parameter 'data' must be of the class 's2dv_cube', ",
-         "as output by CSTools::CST_Load.")
+    stop("Parameter 'data' must be of the class 's2dv_cube'.")
   }
   if (!is.null(insert_ftime)) {
     if (!is.numeric(insert_ftime)) {
