@@ -35,6 +35,35 @@
 #'  colour bar will be automatically interpolated to match the number of breaks. 
 #'  Each item in this list can be named, and the name will be used as title for 
 #'  the corresponding colour bar (equivalent to the parameter 'bar_titles').
+#'@param bar_limits Parameter from s2dv::ColorBar. Vector of two numeric values 
+#'  with the extremes of the range of values represented in the colour bar. If 
+#'  'var_limits' go beyond this interval, the drawing of triangle extremes is 
+#'  triggered at the corresponding sides, painted in 'col_inf' and 'col_sup'. 
+#'  Either of them can be set as NA and will then take as value the 
+#'  corresponding extreme in 'var_limits' (hence a triangle end won't be 
+#'  triggered for these sides). Takes as default the extremes of 'brks' if 
+#'  available, else the same values as 'var_limits'.
+#'@param triangle_ends Parameter from s2dv::ColorBar. Vector of two logical 
+#'  elements, indicating whether to force the drawing of triangle ends at each 
+#'  of the extremes of the colour bar. This choice is automatically made from 
+#'  the provided 'brks', 'bar_limits', 'var_limits', 'col_inf' and 'col_sup', 
+#'  but the behaviour can be manually forced to draw or not to draw the triangle 
+#'  ends with this parameter. If 'cols' is provided, 'col_inf' and 'col_sup' 
+#'  will take priority over 'triangle_ends' when deciding whether to draw the 
+#'  triangle ends or not.
+#'@param col_inf Parameter from s2dv::ColorBar. Colour to fill the inferior 
+#'  triangle end with. Useful if specifying colours manually with parameter 
+#'  'cols', to specify the colour and to trigger the drawing of the lower 
+#'  extreme triangle, or if 'cols' is not specified, to replace the colour 
+#'  automatically generated by ColorBar().
+#'@param col_sup Parameter from s2dv::ColorBar. Colour to fill the superior 
+#'  triangle end with. Useful if specifying colours manually with parameter 
+#'  'cols', to specify the colour and to trigger the drawing of the upper 
+#'  extreme triangle, or if 'cols' is not specified, to replace the colour 
+#'  automatically generated by ColorBar().
+#'@param bar_extra_margin Parameter from s2dv::ColorBar. Extra margins to be 
+#'  added around the colour bar, in the format c(y1, x1, y2, x2). The units are 
+#'  margin lines. Takes rep(0, 4) by default.
 #'@param col_unknown_map Colour to use to paint the grid cells for which a map 
 #'  is not possible to be chosen according to 'map_select_fun' or for those 
 #'  values that go beyond 'display_range'. Takes the value 'white' by default.
@@ -78,6 +107,12 @@
 #'  'down', 'd', 'D', 'bottom', 'b', 'B', 'south', 's', 'S' (default)\cr
 #'  'right', 'r', 'R', 'east', 'e', 'E'\cr
 #'  'left', 'l', 'L', 'west', 'w', 'W' 
+#'@param return_leg A logical value indicating if the color bars information 
+#'  should be returned by the function. If TRUE, the function doesn't plot the
+#'  color bars but still creates the layout with color bar areas, and the 
+#'  arguments for GradientCatsColorBar() or ColorBar() will be returned. It is
+#'  convenient for users to adjust the color bars manually. The default is 
+#'  FALSE, the color bars will be plotted directly.
 #'@param ... Additional parameters to be passed on to \code{PlotEquiMap}.
 #' 
 #'@examples
@@ -121,14 +156,15 @@ PlotCombinedMap <- function(maps, lon, lat,
                             map_select_fun, display_range, 
                             map_dim = 'map',
                             brks = NULL, cols = NULL,  
+                            bar_limits = NULL, triangle_ends = c(F, F), col_inf = NULL, col_sup = NULL,
                             col_unknown_map = 'white',
                             mask = NULL, col_mask = 'grey',
                             dots = NULL,
                             bar_titles = NULL, legend_scale = 1,
                             cex_bar_titles = 1.5,
-                            plot_margin = NULL,
+                            plot_margin = NULL, bar_extra_margin = c(2, 0, 2, 0),
                             fileout = NULL, width = 8, height = 5, 
-                            size_units = 'in', res = 100, drawleg = T,
+                            size_units = 'in', res = 100, drawleg = T, return_leg = FALSE,
                             ...) {
   args <- list(...)
 
@@ -255,12 +291,16 @@ PlotCombinedMap <- function(maps, lon, lat,
   
   # Generate the desired brks and cols. Only nmap, brks, cols, bar_limits, and 
   # bar_titles matter here because plot = F.
-  colorbar <- GradientCatsColorBar(nmap = dim(maps)[map_dim],  
+  var_limits_maps <- range(maps, na.rm = TRUE)
+  if (is.null(bar_limits)) bar_limits <- display_range
+  nmap <- dim(maps)[map_dim]
+  colorbar <- GradientCatsColorBar(nmap = nmap,  
                                    brks = brks, cols = cols, vertical = FALSE,
-                                   subsampleg = NULL, bar_limits = display_range, var_limits = NULL,
-                                   triangle_ends = NULL, plot = FALSE, draw_separators = TRUE,
+                                   subsampleg = NULL, bar_limits = bar_limits,
+                                   var_limits = var_limits_maps,
+                                   triangle_ends = triangle_ends, col_inf = col_inf, col_sup = col_sup, plot = FALSE, draw_separators = TRUE,
                                    bar_titles = bar_titles, title_scale = cex_bar_titles, label_scale = legend_scale * 1.5,
-                                   extra_margin = c(2, 0, 2, 0))
+                                   extra_margin = bar_extra_margin)
   
   # Check legend_scale
   if (!is.numeric(legend_scale)) {
@@ -304,23 +344,38 @@ PlotCombinedMap <- function(maps, lon, lat,
   #----------------------
   # Identify the most likely map
   #----------------------
-  brks_norm <- seq(0, 1, length.out = length(colorbar$brks))
-  if (is.function(map_select_fun)) {
-    range_width <- display_range[2] - display_range[1]
+  #TODO: Consider col_inf
+  if (!is.null(colorbar$col_inf[[1]])) {
+    .warning("Lower triangle is not supported now. Please contact maintainer if you have this need.")
+  }
+  if (!is.null(colorbar$col_sup[[1]])) {
+
+    brks_norm <- vector('list', length = nmap)
+    range_width <- vector('list', length = nmap)
+    slightly_tune_val <- vector('list', length = nmap)
+    for (ii in 1:nmap) {
+      brks_norm[[ii]] <- seq(0, 1, length.out = length(colorbar$brks[[ii]]) + 1)  # add one break for col_sup
+      slightly_tune_val[[ii]] <- brks_norm[[ii]][2] / (length(brks_norm[[ii]]) * 2)
+      range_width[[ii]] <- diff(range(colorbar$brks[[ii]]))
+    }
     ml_map <- apply(maps, c(lat_dim, lon_dim), function(x) {
       if (any(is.na(x))) {
         res <- NA
       } else {
         res <- which(x == map_select_fun(x))
         if (length(res) > 0) {
-          res <- res[1]
-          if (map_select_fun(x) < display_range[1] || 
-              map_select_fun(x) > display_range[2]) {
+          res <- res_ind <- res[1]
+          if (map_select_fun(x) < display_range[1] || map_select_fun(x) > display_range[2]) {
             res <- -0.5
           } else {
-            res <- res + (map_select_fun(x) - display_range[1]) / range_width
-            if (map_select_fun(x) == display_range[1]) {
-	      res <- res + brks_norm[2] / (length(brks_norm) * 2)
+            if (map_select_fun(x) > tail(colorbar$brks[[res_ind]], 1)) { # col_sup
+              res <- res + 1 - slightly_tune_val[[res_ind]]
+            } else {
+              res <- res + ((map_select_fun(x) - colorbar$brks[[res_ind]][1]) /
+                range_width[[res_ind]] * ((length(brks_norm[[res_ind]]) - 2) / (length(brks_norm[[res_ind]]) - 1)))
+              if (map_select_fun(x) == colorbar$brks[[res_ind]][1]) {
+                res <- res + slightly_tune_val[[res_ind]]
+              }
             }
           }
         } else {
@@ -329,18 +384,49 @@ PlotCombinedMap <- function(maps, lon, lat,
       }
       res
     })
+
   } else {
-    stop("Providing 'map_select_fun' as array not implemented yet.")
-    ml_map <- map_select_fun
+
+    brks_norm <- vector('list', length = nmap)
+    range_width <- vector('list', length = nmap)
+    slightly_tune_val <- vector('list', length = nmap)
+    for (ii in 1:nmap) {
+      brks_norm[[ii]] <- seq(0, 1, length.out = length(colorbar$brks[[ii]]))
+      slightly_tune_val[[ii]] <- brks_norm[[ii]][2] / (length(brks_norm[[ii]]) * 2)
+      range_width[[ii]] <- diff(range(colorbar$brks[[ii]]))
+    }
+    ml_map <- apply(maps, c(lat_dim, lon_dim), function(x) {
+      if (any(is.na(x))) {
+        res <- NA
+      } else {
+        res <- which(x == map_select_fun(x))
+        if (length(res) > 0) {
+          res <- res_ind <- res[1]
+          if (map_select_fun(x) < display_range[1] ||
+            map_select_fun(x) > display_range[2]) {
+            res <- -0.5
+          } else {
+              res <- res + ((map_select_fun(x) - colorbar$brks[[res_ind]][1]) /
+                range_width[[res_ind]]) 
+              if (map_select_fun(x) == colorbar$brks[[res_ind]][1]) {
+                res <- res + slightly_tune_val[[res_ind]]
+              }
+          }
+        } else {
+          res <- -0.5
+        }
+      }
+      res
+    })
   }
-  nmap <- dim(maps)[map_dim]
+
   nlat <- length(lat)
   nlon <- length(lon)
   
   #----------------------
   # Set latitudes from minimum to maximum
   #----------------------
-  if (lat[1] > lat[nlat]){
+  if (lat[1] > lat[nlat]) {
     lat <- lat[nlat:1]
     indices <- list(nlat:1, TRUE)
     ml_map <- do.call("[", c(list(x = ml_map), indices))
@@ -373,11 +459,21 @@ PlotCombinedMap <- function(maps, lon, lat,
   #----------------------
   # Set colors and breaks and then PlotEquiMap
   #----------------------
-  tcols <- c(col_unknown_map, colorbar$cols[[1]])
-  for (k in 2:nmap) {
-    tcols <- append(tcols, c(col_unknown_map, colorbar$cols[[k]]))
+ if (!is.null(colorbar$col_sup[[1]])) {
+    tcols <- c(col_unknown_map, colorbar$cols[[1]], colorbar$col_sup[[1]])
+    tbrks <- c(-1, brks_norm[[1]] + rep(1, each = length(brks_norm[[1]])))
+    for (k in 2:nmap) {
+      tcols <- append(tcols, c(col_unknown_map, colorbar$cols[[k]], colorbar$col_sup[[k]]))
+      tbrks <- c(tbrks, brks_norm[[k]] + rep(k, each = length(brks_norm[[k]])))
+    }
+  } else {  # original code
+    tcols <- c(col_unknown_map, colorbar$cols[[1]])
+    tbrks <- c(-1, brks_norm[[1]] + rep(1, each = length(brks_norm[[1]])))
+    for (k in 2:nmap) {
+      tcols <- append(tcols, c(col_unknown_map, colorbar$cols[[k]]))
+      tbrks <- c(tbrks, brks_norm[[k]] + rep(k, each = length(brks_norm[[k]])))
+    }
   }
-  tbrks <- c(-1, brks_norm + rep(1:nmap, each = length(brks_norm)))
 
   if (is.null(plot_margin)) {
     plot_margin <- c(5, 4, 4, 2) + 0.1  # default of par()$mar
@@ -430,16 +526,35 @@ PlotCombinedMap <- function(maps, lon, lat,
     par(mar = old_mar)
   }
 
-  if (drawleg) {
-    GradientCatsColorBar(nmap = dim(maps)[map_dim],  
+  if (drawleg & !return_leg) {
+    GradientCatsColorBar(nmap = dim(maps)[map_dim],
                          brks = colorbar$brks, cols = colorbar$cols, vertical = FALSE,
-                         subsampleg = NULL, bar_limits = display_range, var_limits = NULL,
-                         triangle_ends = NULL, plot = TRUE, draw_separators = TRUE,
+                         subsampleg = NULL, bar_limits = bar_limits,
+                         var_limits = var_limits_maps,
+                         triangle_ends = triangle_ends, col_inf = colorbar$col_inf, col_sup = colorbar$col_sup,
+                         plot = TRUE, draw_separators = TRUE,
                          bar_titles = bar_titles, title_scale = cex_bar_titles, label_scale = legend_scale * 1.5,
-                         extra_margin = c(2, 0, 2, 0))
+                         extra_margin = bar_extra_margin)
   }
-  
-  # If the graphic was saved to file, close the connection with the device
-  if (!is.null(fileout)) dev.off()
+
+  if (!return_leg) {
+    # If the graphic was saved to file, close the connection with the device
+    if (!is.null(fileout)) dev.off()
+  }
+
+  if (return_leg) {
+    tmp <- list(nmap = dim(maps)[map_dim],
+                brks = colorbar$brks, cols = colorbar$cols, vertical = FALSE,
+                subsampleg = NULL, bar_limits = bar_limits,
+                var_limits = var_limits_maps,
+                triangle_ends = triangle_ends, col_inf = colorbar$col_inf, col_sup = colorbar$col_sup,
+                plot = TRUE, draw_separators = TRUE,
+                bar_titles = bar_titles, title_scale = cex_bar_titles, label_scale = legend_scale * 1.5,
+                extra_margin = bar_extra_margin)
+    .warning("The device is not off yet. Use dev.off() after plotting the color bars.")
+    return(tmp)
+    #NOTE: The device is not off! Can keep plotting the color bars.
+  }
+
 }
 
